pub enum ThinkingConfig {
Disabled,
Enabled {
budget_tokens: Option<u32>,
},
}Expand description
Thinking chain configuration. Providers that do not support the concept of a thinking
chain should ignore the budget field of Enabled, or report
super::FeatureSupport::Unsupported in the capability matrix.
Variants
Disabled
Enabled
Enable thinking chain; budget_tokens is only used by providers that support
budgets, such as Anthropic.